@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
-# $Id: ECAssignment.py 1296 2009-09-27 18:28:47Z amelung $
+# $Id: ECAssignment.py 1570 2011-06-28 22:33:33Z amelung $
 #
-# Copyright (c) 2006-2009 Otto-von-Guericke University Magdeburg
+# Copyright (c) 2006-2011 Otto-von-Guericke-UniversitŠt Magdeburg
 #
 # This file is part of ECAssignmentBox.
 #
 __author__ = """Mario Amelung <mario.amelung@gmx.de>"""
 __docformat__ = 'plaintext'
-__version__   = '$Revision: 1.2 $'
 
 import re
 import interfaces
@@ -30,16 +29,17 @@ from Products.ATContentTypes.lib.historyaware import HistoryAwareMixin
 
 # The following two imports are for getAsPlainText()
 #from Products.ATContentTypes.content.base import translateMimetypeAlias
-from Products.PortalTransforms.utils import TransformException
+#from Products.PortalTransforms.utils import TransformException
 
 from Products.ECAssignmentBox import config
+from Products.ECAssignmentBox import LOG
 
 # PlagDetector imports
 from Products.ECAssignmentBox.PlagDetector.PlagChecker import PlagChecker
 from Products.ECAssignmentBox.PlagDetector.PlagVisualizer import PlagVisualizer
 
-import logging
-log = logging.getLogger('ECAssignmentBox')
+#import logging
+#log = logging.getLogger('ECAssignmentBox')
 
 # alter default fields -> hide title and description
 ECAssignmentSchema = ATContentTypeSchema.copy()
@@ -75,9 +75,9 @@ ECAssignmentSchema = ECAssignmentSchema + Schema((
 
     TextField(
         'remarks',
-        allowable_content_types = config.ECA_MIME_TYPES, 
-        default_content_type = config.EC_DEFAULT_MIME_TYPE, 
-        default_output_type = config.EC_DEFAULT_FORMAT,
+        allowable_content_types = config.ALLOWED_CONTENT_TYPES, 
+        default_content_type = config.DEFAULT_CONTENT_TYPE, 
+        default_output_type = config.DEFAULT_OUTPUT_TYPE,
         widget=RichWidget(
         #widget = TextAreaWidget(
             label = "Remarks",
@@ -93,9 +93,9 @@ ECAssignmentSchema = ECAssignmentSchema + Schema((
     TextField(
         'feedback',
         searchable = True,
-        allowable_content_types = config.ECA_MIME_TYPES, 
-        default_content_type = config.EC_DEFAULT_MIME_TYPE, 
-        default_output_type = config.EC_DEFAULT_FORMAT,
+        allowable_content_types = config.ALLOWED_CONTENT_TYPES, 
+        default_content_type = config.DEFAULT_CONTENT_TYPE, 
+        default_output_type = config.DEFAULT_OUTPUT_TYPE,
         widget=RichWidget(
         #widget = TextAreaWidget(
             label = "Feedback",
@@ -174,7 +174,7 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
         When this assignment is created, send a notification email to
         the owner of the assignment box, unless emailing is turned off.
         """
-        #log.debug('Here we are in ECAssignmentBox#sendNotificationEmail')
+        #LOG.debug('Here we are in ECAssignmentBox#sendNotificationEmail')
 
         box = self.aq_parent
         
@@ -228,7 +228,7 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
                                            'version': productVersion},
                                   default=default_mailText)
 
-        log.info('Sending notification email to: %s' % addresses)
+        LOG.info('Sending notification email to: %s' % addresses)
         ecab_utils.sendEmail(addresses, subject, mailText)
 
     #security.declarePrivate('sendGradingNotificationEmail')
@@ -285,7 +285,7 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
                                            'version': productVersion},
                                   default=default_mailText)
 
-        log.info('Sending grading notification email to %s' % addresses)
+        LOG.info('Sending grading notification email to %s' % addresses)
         ecab_utils.sendEmail(addresses, subject, mailText)
 
 
@@ -304,8 +304,7 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
     def _generateTitle(self):
         """
         """
-        #log("Title changed from '%s' to '%s'" % \
-        #        (self.title, self.getCreatorFullName(),), severity=DEBUG)
+        #LOG.info("xdebug: Title changed from '%s' to '%s'" % (self.title, self.getCreatorFullName(),))
         return self.getCreatorFullName()
 
 
@@ -332,14 +331,17 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
 
         @return file content
         """
+        result = None
+        
         mt = self.getContentType('file')
         
         if re.match("(text/.+)|(application/(.+\+)?xml)", mt):
         
             box = self.aq_parent
             
-            if ((mt == 'text/plain') or
-                (mt == 'text/x-web-intelligent')) and box.getWrapAnswer():
+            if (box.getWrapAnswer() and 
+                ((mt == 'text/plain') or (mt == 'text/x-web-intelligent'))): 
+                
                 file = StringIO(self.getField('file').get(self))
                 wrap = TextWrapper()
                 result = ''
@@ -347,12 +349,14 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
                 for line in file:
                     result += wrap.fill(line) + '\n'
     
-                return result
             else:
-                return self.getField('file').get(self)
-        else:
-            return None
+                result = str(self.getField('file').get(self))
+        # end if
+
+        # take care of hexadecimal Unicode escape sequences
+        #if result: result = result.decode('unicode_escape')
         
+        return result
     
     #security.declarePublic('getAsPlainText')
     def getAsPlainText(self):
@@ -367,10 +371,7 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
         
         @return file content as plain text or None
         """
-        ptTool = getToolByName(self, 'portal_transforms')
         f = self.getField('file')
-        #source = ''
-
         mt = self.getContentType('file')
         
         if re.match('text/|application/(.+\+)?xml', mt):
@@ -378,7 +379,9 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
         else:
             return None
         
+        """
         try:
+            ptTool = getToolByName(self, 'portal_transforms')
             result = ptTool.convertTo('text/plain-pre', str(f.get(self)),
                                       mimetype=mt)
         except TransformException:
@@ -388,6 +391,7 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
             return result.getData()
         else:
             return None
+        """
     
     
     security.declarePublic('evaluate')
@@ -653,6 +657,12 @@ class ECAssignment(BaseContent, HistoryAwareMixin):
                              showIdNums=True)
         return image
 
+ 
+    security.declarePublic('getLayout')
+    def getLayout(self):
+        """This exists to please the discussion form."""
+        return 'eca_view'
 
+ 
 registerType(ECAssignment, config.PROJECTNAME)
 # end of class ECAssignment
